@@ -12,12 +12,12 @@ from pymatgen import Element, MPRester
 from pymatgen.core.composition import Composition
 from pymatgen.core.molecular_orbitals import MolecularOrbitals
 from pymatgen.core.periodic_table import get_el_sp
-from sklearn.neighbors.unsupervised import NearestNeighbors
+from sklearn.neighbors import NearestNeighbors
 
 from matminer.featurizers.base import BaseFeaturizer
 from matminer.featurizers.utils.stats import PropertyStats
 from matminer.utils.data import DemlData, MagpieData, PymatgenData, \
-    CohesiveEnergyData, MixingEnthalpy
+    CohesiveEnergyData, MixingEnthalpy, MatscholarElementData, MEGNetElementData
 
 __author__ = 'Logan Ward, Jiming Chen, Ashwin Aggarwal, Kiran Mathew, ' \
              'Saurabh Bajaj, Qi Wang, Maxwell Dylla, Anubhav Jain'
@@ -33,9 +33,9 @@ def has_oxidation_states(comp):
     TODO: Does this make sense to add to pymatgen? -wardlt
 
     Args:
-        comp - (Composition) Composition to check
+        comp (Composition): Composition to check
     Returns:
-        (Boolean) Whether this composition object contains oxidation states
+        (boolean) Whether this composition object contains oxidation states
     """
     for el in comp.elements:
         if not hasattr(el, "oxi_state") or el.oxi_state is None:
@@ -43,12 +43,50 @@ def has_oxidation_states(comp):
     return True
 
 
+def is_ionic(comp):
+    """Determines whether a compound is an ionic compound.
+
+    Looks at the oxidation states of each site and checks if both anions and cations exist
+
+    Args:
+        comp (Composition): Composition to check
+    Returns:
+        (bool) Whether the composition describes an ionic compound
+    """
+
+    has_cations = False
+    has_anions = False
+
+    for el in comp.elements:
+        if el.oxi_state < 0:
+            has_anions = True
+        if el.oxi_state > 0:
+            has_cations = True
+        if has_anions and has_cations:
+            return True
+    return False
+
+
 class ElementProperty(BaseFeaturizer):
     """
     Class to calculate elemental property attributes.
 
     To initialize quickly, use the from_preset() method.
 
+    Features: Based on the statistics of the data_source chosen, computed
+    by element stoichiometry. The format generally is:
+
+    "{data source} {statistic} {property}"
+
+    For example:
+
+    "PymetgenData range X"  # Range of electronegativity from Pymatgen data
+
+    For a list of all statistics, see the PropertyStats documentation; for a
+    list of all attributes available for a given data_source, see the
+    documentation for the data sources (e.g., PymatgenData, MagpieData,
+    MatscholarElementData, etc.).
+
     Args:
         data_source (AbstractData or str): source from which to retrieve
             element property data (or use str for preset: "pymatgen",
@@ -66,21 +104,28 @@ class ElementProperty(BaseFeaturizer):
             self.data_source = MagpieData()
         elif data_source == "deml":
             self.data_source = DemlData()
+        elif data_source == "matscholar_el":
+            self.data_source = MatscholarElementData()
+        elif data_source == "megnet_el":
+            self.data_source = MEGNetElementData()
         else:
             self.data_source = data_source
 
         self.features = features
         self.stats = stats
+        # Initialize stats computer
+        self.pstats = PropertyStats()
 
     @classmethod
     def from_preset(cls, preset_name):
         """
         Return ElementProperty from a preset string
         Args:
-            preset_name: (str) can be one of "magpie", "deml", or "matminer"
+            preset_name: (str) can be one of "magpie", "deml", "matminer",
+                "matscholar_el", or "megnet_el".
 
         Returns:
-
+            ElementProperty based on the preset name.
         """
         if preset_name == "magpie":
             data_source = "magpie"
@@ -114,6 +159,16 @@ class ElementProperty(BaseFeaturizer):
                         "bulk_modulus",
                         "coefficient_of_linear_thermal_expansion"]
 
+        elif preset_name == "matscholar_el":
+            data_source = "matscholar_el"
+            stats = ["minimum", "maximum", "range", "mean", "std_dev"]
+            features = MatscholarElementData().prop_names
+
+        elif preset_name == "megnet_el":
+            data_source = "megnet_el"
+            stats = ["minimum", "maximum", "range", "mean", "std_dev"]
+            features = MEGNetElementData().prop_names
+
         else:
             raise ValueError("Invalid preset_name specified!")
 
@@ -132,9 +187,6 @@ class ElementProperty(BaseFeaturizer):
 
         all_attributes = []
 
-        # Initialize stats computer
-        pstats = PropertyStats()
-
         # Get the element names and fractions
         elements, fractions = zip(*comp.element_composition.items())
 
@@ -142,15 +194,16 @@ class ElementProperty(BaseFeaturizer):
             elem_data = [self.data_source.get_elemental_property(e, attr) for e in elements]
 
             for stat in self.stats:
-                all_attributes.append(pstats.calc_stat(elem_data, stat, fractions))
+                all_attributes.append(self.pstats.calc_stat(elem_data, stat, fractions))
 
         return all_attributes
 
     def feature_labels(self):
         labels = []
         for attr in self.features:
+            src = self.data_source.__class__.__name__
             for stat in self.stats:
-                labels.append("%s %s" % (stat, attr))
+                labels.append("{} {} {}".format(src, stat, attr))
         return labels
 
     def citations(self):
@@ -177,45 +230,148 @@ class ElementProperty(BaseFeaturizer):
                 "publisher = {Elsevier B.V.}, title = {{Python Materials Genomics (pymatgen): A robust, open-source python "
                 "library for materials analysis}}, url = {http://linkinghub.elsevier.com/retrieve/pii/S0927025612006295}, "
                 "volume = {68}, year = {2013} } "]
+        elif self.data_source.__class__.__name__ == "MEGNetElementData":
+            # TODO: Cite MEGNet publication (not preprint) once released!
+            citation = [
+                "@ARTICLE{2018arXiv181205055C,"
+                "author = {{Chen}, Chi and {Ye}, Weike and {Zuo}, Yunxing and {Zheng}, Chen and {Ong}, Shyue Ping},"
+                "title = '{Graph Networks as a Universal Machine Learning Framework for Molecules and Crystals}',"
+                "journal = {arXiv e-prints},"
+                "keywords = {Condensed Matter - Materials Science, Physics - Computational Physics},"
+                "year = '2018',"
+                "month = 'Dec',"
+                "eid = {arXiv:1812.05055},"
+                "pages = {arXiv:1812.05055},"
+                "archivePrefix = {arXiv},"
+                "eprint = {1812.05055},"
+                "primaryClass = {cond-mat.mtrl-sci},"
+                "adsurl = {https://ui.adsabs.harvard.edu/\#abs/2018arXiv181205055C},"
+                "adsnote = {Provided by the SAO/NASA Astrophysics Data System}}"]
         else:
             citation = []
         return citation
 
     def implementors(self):
-        return ["Jiming Chen", "Logan Ward", "Anubhav Jain"]
+        return ["Jiming Chen", "Logan Ward", "Anubhav Jain", "Alex Dunn"]
+
+class Meredig(BaseFeaturizer):
+    """
+    Class to calculate features as defined in Meredig et. al.
+
+    Features:
+        Atomic fraction of each of the first 103 elements, in order of atomic number.
+        17 statistics of elemental properties;
+            Mean atomic weight of constituent elements
+            Mean periodic table row and column number
+            Mean and range of atomic number
+            Mean and range of atomic radius
+            Mean and range of electronegativity
+            Mean number of valence electrons in each orbital
+            Fraction of total valence electrons in each orbital
+
+    """
+
+    def __init__(self):
+        self.data_source = MagpieData()
+
+        #The labels for statistics on element properties
+        self._element_property_feature_labels = ["mean AtomicWeight", "mean Column", "mean Row", "range Number", "mean Number",
+        "range AtomicRadius", "mean AtomicRadius", "range Electronegativity", "mean Electronegativity"]
+        # Initialize stats computer
+        self.pstats = PropertyStats()
+
+    def featurize(self, comp):
+        """
+        Get elemental property attributes
+
+        Args:
+            comp: Pymatgen composition object
+
+        Returns:
+            all_attributes: Specified property statistics of features
+        """
+
+        #First 103 features are element fractions, we can get these from the ElementFraction featurizer
+        element_fraction_features = ElementFraction().featurize(comp)
+
+
+        #Next 9 features are statistics on elemental properties
+        elements, fractions = zip(*comp.element_composition.items())
+        element_property_features = [0] * len(self._element_property_feature_labels)
+
+        for i,feat in enumerate(self._element_property_feature_labels):
+            stat = feat.split(" ")[0]
+            attr = " ".join(feat.split(" ")[1:])
+
+            elem_data = [self.data_source.get_elemental_property(e, attr) for e in elements]
+            element_property_features[i] = self.pstats.calc_stat(elem_data, stat, fractions)
+
+        #Final 8 features are statistics on valence orbitals, available from the ValenceOrbital featurizer
+        valence_orbital_features = ValenceOrbital(orbitals=("s", "p", "d", "f"), props=("avg", "frac")).featurize(comp)
+
+        return element_fraction_features+element_property_features+valence_orbital_features
+
+    def feature_labels(self):
+        #Since we have more features than just element fractions, append 'fraction' to element symbols for clarity
+        element_fraction_features = [e + " fraction" for e in ElementFraction().feature_labels()]
+        valence_orbital_features = ValenceOrbital().feature_labels()
+        return element_fraction_features+self._element_property_feature_labels+valence_orbital_features
+
+    def citations(self):
+        citation = [
+            "@article{meredig_agrawal_kirklin_saal_doak_thompson_zhang_choudhary_wolverton_2014, title={Combinatorial "
+            "screening for new materials in unconstrained composition space with machine learning}, "
+            "volume={89}, DOI={10.1103/PhysRevB.89.094104}, number={1}, journal={Physical "
+            "Review B}, author={B. Meredig, A. Agrawal, S. Kirklin, J. E. Saal, J. W. Doak, A. Thompson, "
+            "K. Zhang, A. Choudhary, and C. Wolverton}, year={2014}}"]
+        return citation
+
+    def implementors(self):
+        return ["Amalie Trewartha"]
 
 
 class CationProperty(ElementProperty):
     """
     Features based on properties of cations in a material
 
-    Requires that oxidation states have already been determined
+    Requires that oxidation states have already been determined. Property
+    statistics weighted by composition.
 
-    Computes composition-weighted statistics of different elemental properties
+    Features: Based on the statistics of the data_source chosen, computed
+    by element stoichiometry. The format generally is:
+
+    "{data source} {statistic} {property}"
+
+    For example:
+
+    "DemlData range magn_moment" # Range of magnetic moment via Deml et al. data
+
+    For a list of all statistics, see the PropertyStats documentation; for a
+    list of all attributes available for a given data_source, see the
+    documentation for the data sources (e.g., PymatgenData, MagpieData,
+    MatscholarElementData, etc.).
     """
 
     @classmethod
     def from_preset(cls, preset_name):
         if preset_name == "deml":
             data_source = "deml"
-            features = ["total_ioniz", "xtal_field_split", "magn_moment", "so_coupling", "sat_magn"]
+            features = ["total_ioniz", "xtal_field_split", "magn_moment",
+                        "so_coupling", "sat_magn"]
             stats = ["minimum", "maximum", "range", "mean", "std_dev"]
         else:
-            raise ValueError('Preset "%s" not found'%preset_name)
+            raise ValueError('Preset "%s" not found' % preset_name)
         return cls(data_source, features, stats)
 
     def feature_labels(self):
-        labels = []
-        for attr in self.features:
-            for stat in self.stats:
-                labels.append("%s %s of cations"%(stat, attr))
-
-        return labels
+        return [f + " of cations" for f in super().feature_labels()]
 
     def featurize(self, comp):
         # Check if oxidation states are present
         if not has_oxidation_states(comp):
             raise ValueError('Oxidation states have not been determined')
+        if not is_ionic(comp):
+            raise ValueError('Composition is not ionic')
 
         # Prepare to store the attributes
         all_attributes = []
@@ -452,6 +608,8 @@ class ElectronegativityDiff(BaseFeaturizer):
         # Check if oxidation states have been determined
         if not has_oxidation_states(comp):
             raise ValueError('Oxidation states have not yet been determined')
+        if not is_ionic(comp):
+            raise ValueError('Composition is not ionic')
 
         # Determine the average anion EN
         anions, anion_fractions = zip(*[(s, x) for s, x in comp.items() if s.oxi_state < 0])
@@ -925,18 +1083,17 @@ class CohesiveEnergy(BaseFeaturizer):
                 your compound. If not set, will look up the most stable
                 formation energy from the Materials Project database.
         """
+        comp = comp.reduced_composition
         el_amt_dict = comp.get_el_amt_dict()
 
         formation_energy_per_atom = formation_energy_per_atom or None
 
         if not formation_energy_per_atom:
             # Get formation energy of most stable structure from MP
-            struct_lst = MPRester(self.mapi_key).get_data(
-                comp.formula.replace(" ", ""))
+            struct_lst = MPRester(self.mapi_key).get_data(comp.reduced_formula)
             if len(struct_lst) > 0:
                 most_stable_entry = sorted(struct_lst, key=lambda e: e['energy_per_atom'])[0]
-                formation_energy_per_atom = most_stable_entry[
-                    'formation_energy_per_atom']
+                formation_energy_per_atom = most_stable_entry['formation_energy_per_atom']
             else:
                 raise ValueError('No structure found in MP for {}'.format(comp))
 
@@ -968,6 +1125,67 @@ class CohesiveEnergy(BaseFeaturizer):
             "Physics, 8th Edition}}, year = {2005}}"]
 
 
+class CohesiveEnergyMP(BaseFeaturizer):
+    """
+    Cohesive energy per atom lookup using Materials Project
+
+    Parameters:
+        mapi_key (str): Materials API key for looking up cohesive energy
+            by composition alone.
+    """
+
+    def __init__(self, mapi_key=None):
+        self.mapi_key = mapi_key
+
+    def featurize(self, comp):
+        """
+
+        Args:
+            comp: (str) compound composition, eg: "NaCl"
+        """
+
+        # Get formation energy of most stable structure from MP
+        with MPRester(self.mapi_key) as mpr:
+            struct_lst = mpr.get_data(comp.reduced_formula)
+            if len(struct_lst) > 0:
+                most_stable_entry = sorted(struct_lst, key=lambda e: e['energy_per_atom'])[0]
+                try:
+                    return [mpr.get_cohesive_energy(most_stable_entry["material_id"], per_atom=True)]
+                except:
+                    raise ValueError("No cohesive energy can be determined for material_id: {}".format(most_stable_entry["material_id"]))
+            else:
+                raise ValueError('No structure found in MP for {}'.format(comp))
+
+    def feature_labels(self):
+        return ["cohesive energy (MP)"]
+
+    def implementors(self):
+        return ["Anubhav Jain"]
+
+    def citations(self):
+        return [
+            "@article{doi:10.1063/1.4812323, author = {Jain,Anubhav and Ong,"
+            "Shyue Ping  and Hautier,Geoffroy and Chen,Wei and Richards, "
+            "William Davidson  and Dacek,Stephen and Cholia,Shreyas "
+            "and Gunter,Dan  and Skinner,David and Ceder,Gerbrand "
+            "and Persson,Kristin A. }, title = {Commentary: The Materials "
+            "Project: A materials genome approach to accelerating materials "
+            "innovation}, journal = {APL Materials}, volume = {1}, number = "
+            "{1}, pages = {011002}, year = {2013}, doi = {10.1063/1.4812323}, "
+            "URL = {https://doi.org/10.1063/1.4812323}, "
+            "eprint = {https://doi.org/10.1063/1.4812323}}",
+            "@article{Ong2015, author = {Ong, Shyue Ping and Cholia, "
+            "Shreyas and Jain, Anubhav and Brafman, Miriam and Gunter, Dan "
+            "and Ceder, Gerbrand and Persson, Kristin a.}, doi = "
+            "{10.1016/j.commatsci.2014.10.037}, issn = {09270256}, "
+            "journal = {Computational Materials Science}, month = {feb}, "
+            "pages = {209--215}, publisher = {Elsevier B.V.}, title = "
+            "{{The Materials Application Programming Interface (API): A simple, "
+            "flexible and efficient API for materials data based on "
+            "REpresentational State Transfer (REST) principles}}, "
+            "url = {http://linkinghub.elsevier.com/retrieve/pii/S0927025614007113}, "
+            "volume = {97}, year = {2015} } "]
+
 class Miedema(BaseFeaturizer):
     """
     Formation enthalpies of intermetallic compounds, from Miedema et al.
@@ -976,59 +1194,43 @@ class Miedema(BaseFeaturizer):
     solid solution and amorphous phase of a given composition, based on
     semi-empirical Miedema model (and some extensions), particularly for
     transitional metal alloys.
+
     Support elemental, binary and multicomponent alloys.
-        For elemental/binary alloys, the formulation is based on the original
-        works by Miedema et al. in 1980s;
-        For multicomponent alloys, the formulation is basically the linear
-        combination of sub-binary systems. This is reported to work well for
-        ternary alloys, but needs to be careful with quaternary alloys and more.
+    For elemental/binary alloys, the formulation is based on the original
+    works by Miedema et al. in 1980s;
+    For multicomponent alloys, the formulation is basically the linear
+    combination of sub-binary systems. This is reported to work well for
+    ternary alloys, but needs to be careful with quaternary alloys and more.
 
     Args:
-        struct_types (str or list of str): default='inter'
-            if str, one target structure;
-            if list, a list of target structures.
-            e.g.
-            'inter': intermetallic compound
-            'ss': solid solution
-            'amor': amorphous phase
-            'all': same for ['inter', 'ss', 'amor']
-            ['inter', 'ss']: amorphous phase and solid solution, as an example
-        ss_types (str or list of str): only for ss, default='min'
-            if str, one structure type of ss;
-            if list, a list of structure types of ss.
-            e.g.
-            'fcc': fcc solid solution
-            'bcc': bcc solid solution
-            'hcp': hcp solid solution
+        struct_types (str or [str]): default='all'
+            'inter': intermetallic compound; 'ss': solid solution
+            'amor': amorphous phase; 'all': same for ['inter', 'ss', 'amor']
+            ['inter', 'ss']: amorphous phase and solid solution
+        ss_types (str or [str]): only for ss, default='min'
+            'fcc': fcc solid solution; 'bcc': bcc solid solution
+            'hcp': hcp solid solution;
             'no_latt': solid solution with no specific structure type
             'min': min value of ['fcc', 'bcc', 'hcp', 'no_latt']
             'all': same for ['fcc', 'bcc', 'hcp', 'no_latt']
-            ['fcc', 'bcc']: fcc and bcc solid solutions, as an example
-        data_source (str): default='Miedema', source of dataset
-            'Miedema': read from 'Miedema.csv'
-                        parameterized by Miedema et al. in 1980s,
-                        containing parameters for 73 types of elements:
-                         'molar_volume'
-                         'electron_density'
-                         'electronegativity'
-                         'valence_electrons'
-                         'a_const'
-                         'R_const'
-                         'H_trans'
-                         'compressibility'
-                         'shear_modulus'
-                         'melting_point'
-                         'structural_stability'
+            ['fcc', 'bcc']: fcc and bcc solid solutions
+        data_source (str): source of dataset, default='Miedema'
+            'Miedema': 'Miedema.csv' placed in "matminer/utils/data_files/",
+            containing the following model parameters for 73 elements:
+            'molar_volume', 'electron_density', 'electronegativity'
+            'valence_electrons', 'a_const', 'R_const', 'H_trans'
+            'compressibility', 'shear_modulus', 'melting_point'
+            'structural_stability'. Please see the references for details.
     Returns:
-        (list of floats) Miedema formation enthalpies (per atom)
-            -formation_enthalpy_inter: for intermetallic compound
-            -formation_enthalpy_ss: for solid solution, can be divided into
-                                   'min', 'fcc', 'bcc', 'hcp', 'no_latt'
-                                    for different lattice_types
-            -formation_enthalpy_amor: for amorphous phase
+        (list of floats) Miedema formation enthalpies (eV/atom) for input
+            struct_types:
+            -Miedema_deltaH_inter: for intermetallic compound
+            -Miedema_deltaH_ss: for solid solution, can include 'fcc', 'bcc',
+                'hcp', 'no_latt', 'min' based on input ss_types
+            -Miedema_deltaH_amor: for amorphous phase
     """
 
-    def __init__(self, struct_types='inter', ss_types='min',
+    def __init__(self, struct_types='all', ss_types='min',
                  data_source='Miedema'):
         if isinstance(struct_types, list):
             self.struct_types = struct_types
@@ -1054,6 +1256,25 @@ class Miedema(BaseFeaturizer):
             raise NotImplementedError('data_source {} not implemented yet'.
                                       format(self, data_source))
 
+        self.element_list = [Element(estr) for estr in self.df_dataset.index]
+
+    def precheck(self, c: Composition) -> bool:
+        """
+        Precheck a single entry. Miedema does not work for compositons
+        containing any elments for which the Miedema model has no parameters.
+        To precheck an entire dataframe (qnd automatically gather
+        the fraction of structures that will pass the precheck), please use
+        precheck_dataframe.
+
+        Args:
+            c (pymatgen.Composition): The composition to precheck.
+
+        Returns:
+            (bool): If True, s passed the precheck; otherwise, it failed.
+        """
+        return all([e in self.element_list
+                    for e in c.element_composition.elements])
+
     def deltaH_chem(self, elements, fracs, struct):
         """
         Chemical term of formation enthalpy
@@ -1362,13 +1583,33 @@ class YangSolidSolution(BaseFeaturizer):
         # Load in a table of elemental properties
         self.elem_data = MagpieData()
 
+    def precheck(self, c: Composition) -> bool:
+        """
+        Precheck a single entry. YangSolidSolution does not work for compositons
+        containing any binary elment combinations for which the model has no
+        parameters. We can nearly equivalently approximate this by checking
+        against the unary element list.
+
+        To precheck an entire dataframe (qnd automatically gather
+        the fraction of structures that will pass the precheck), please use
+        precheck_dataframe.
+
+        Args:
+            c (pymatgen.Composition): The composition to precheck.
+
+        Returns:
+            (bool): If True, s passed the precheck; otherwise, it failed.
+        """
+        return all([e in self.dhf_mix.valid_element_list
+                    for e in c.element_composition.elements])
+
     def featurize(self, comp):
         return [self.compute_omega(comp), self.compute_delta(comp)]
 
     def compute_omega(self, comp):
         """Compute Yang's mixing thermodynamics descriptor
 
-        :math:`\frac{T_m \Delta S_{mix}}{ |  \Delta H_{mix} | }`
+        :math:`\\frac{T_m \Delta S_{mix}}{ |  \Delta H_{mix} | }`
 
         Where :math:`T_m` is average melting temperature,
         :math:`\Delta S_{mix}` is the ideal mixing entropy,
@@ -1404,15 +1645,20 @@ class YangSolidSolution(BaseFeaturizer):
                 enthalpy += f1 * f2 * self.dhf_mix.get_mixing_enthalpy(e1, e2)
         enthalpy *= 4
 
+        # Make sure the enthalpy is nonzero
+        #  The limit as dH->0 of omega is +\inf. A very small positive dH will approximate
+        #  this limit without causing issues with infinite features
+        enthalpy = max(1e-6, abs(enthalpy))
+
         return abs(mean_Tm * entropy / enthalpy)
 
     def compute_delta(self, comp):
         """Compute Yang's delta parameter
 
-        :math:`\sqrt{\sum^n_{i=1} c_i \left( 1 - \frac{r_i}{\bar{r}} \right)^2 }`
+        :math:`\sqrt{\sum^n_{i=1} c_i \left( 1 - \\frac{r_i}{\\bar{r}} \\right)^2 }`
 
         where :math:`c_i` and :math:`r_i` are the fraction and radius of
-        element :math:`i`, and :math:`\bar{r}` is the fraction-weighted
+        element :math:`i`, and :math:`\\bar{r}` is the fraction-weighted
         average of the radii. We use the radii compiled by
         .. Miracle et al. `https://www.tandfonline.com/doi/ref/10.1179/095066010X12646898728200?scroll=top`.
 
@@ -1430,7 +1676,7 @@ class YangSolidSolution(BaseFeaturizer):
                                                         "MiracleRadius")
         mean_r = PropertyStats.mean(radii, fractions)
 
-        # Compute the mean (1 - r/\bar{r})^2
+        # Compute the mean (1 - r/\\bar{r})^2
         r_dev = np.power(1.0 - np.divide(radii, mean_r), 2)
         return np.sqrt(PropertyStats.mean(r_dev, fractions))
 
@@ -1717,7 +1963,7 @@ class AtomicPackingEfficiency(BaseFeaturizer):
         ratio for a certain :math:`n` and :math:`r` is the actual ratio.
 
         Args:
-            radius_ratio (float): math:`r / r_{neighbor}`
+            radius_ratio (float): :math:`r / r_{neighbor}`
         Returns:
             (int) number of neighboring atoms for that will be the most
             efficiently packed.
