@@ -26,7 +26,7 @@ from matminer.featurizers.structure import DensityFeatures, \
     EwaldEnergy, BondFractions, BagofBonds, StructuralHeterogeneity, \
     MaximumPackingEfficiency, ChemicalOrdering, StructureComposition, \
     Dimensionality, XRDPowderPattern, CGCNNFeaturizer, JarvisCFID, \
-    SOAP, GlobalInstabilityIndex, \
+    GlobalInstabilityIndex, \
     StructuralComplexity
 
 # For the CGCNNFeaturizer
@@ -439,14 +439,10 @@ class StructureFeaturesTest(PymatgenTest):
         # Test basic
         ewald = EwaldEnergy(accuracy=2)
         self.assertArrayAlmostEqual(ewald.featurize(self.diamond), [0])
-        self.assertAlmostEqual(ewald.featurize(self.nacl)[0], -8.84173626, 2)
+        self.assertAlmostEqual(ewald.featurize(self.nacl)[0], -4.418439, 2)
         self.assertLess(ewald.featurize(self.nacl),
                         ewald.featurize(self.cscl))  # Atoms are closer in NaCl
 
-        # Perform Ewald summation by "hand",
-        #  Using the result from GULP
-        self.assertArrayAlmostEqual([-8.84173626], ewald.featurize(self.nacl), 2)
-
     def test_bondfractions(self):
 
         # Test individual structures with featurize
@@ -844,26 +840,6 @@ class StructureFeaturesTest(PymatgenTest):
         self.assertAlmostEqual(fvec[-1], 24, places=3)
         self.assertAlmostEqual(fvec[0], 0, places=3)
 
-    def test_SOAP(self):
-        # Test individual samples
-        soap = SOAP(n_max=4, l_max=2, r_cut=3.0)
-        soap.fit([self.diamond])
-        v = soap.featurize(self.diamond)
-        self.assertEqual(len(v), 30)
-        self.assertAlmostEqual(v[0], 5.299793243408203, places=6)
-
-        soap.fit([self.ni3al])
-        v = soap.featurize(self.ni3al)
-        self.assertEqual(len(v), 90)
-        self.assertAlmostEqual(v[0], 0.10329483449459076, places=6)
-
-        # Test dataframe fitting
-        df = pd.DataFrame({"s": [self.diamond, self.ni3al, self.nacl]})
-        soap.fit(df["s"])
-        df = soap.featurize_dataframe(df, "s", inplace=False)
-        self.assertTupleEqual(df.shape, (3, 451))
-        self.assertAlmostEqual(df["SOAP_449"].iloc[1], 3.029167413711548, places=5)
-
     def test_GlobalInstabilityIndex(self):
         # Test diamond and ni3al fail precheck
         gii = GlobalInstabilityIndex(r_cut=4.0, disordered_pymatgen=False)
@@ -925,3 +901,6 @@ class StructureFeaturesTest(PymatgenTest):
         ig, igbits = featurizer.featurize(s)
 
         self.assertAlmostEqual(3.764, ig, places=3)
+
+if __name__ == '__main__':
+    unittest.main()
